@@ -33,7 +33,7 @@ use DNS::Unbound::X ();
 our ($VERSION);
 
 BEGIN {
-    $VERSION = '0.02_01';
+    $VERSION = '0.04_01';
     XSLoader::load();
 }
 
@@ -220,13 +220,21 @@ sub decode_character_strings {
 #----------------------------------------------------------------------
 
 sub DESTROY {
-    _destroy_context( $_[0][0] );
+    $_[0][1] ||= do {
+        _destroy_context( $_[0][0] );
+        1;
+    };
 }
 
 #----------------------------------------------------------------------
 
+1;
+
 =head1 REPOSITORY
 
 L<https://github.com/FGasper/p5-DNS-Unbound>
 
-1;
+=head1 THANK YOU
+
+Special thanks to L<ATOOMIC|https://metacpan.org/author/ATOOMIC> for
+making some helpful review notes.
